@@ -17,7 +17,7 @@ from functools import wraps
 import requests
 from flask import redirect, request, json
 
-__version__ = '2.0.0'
+__version__ = '2.0.1'
 
 _logger = logging.getLogger(__name__)
 # Add NullHandler to prevent logging warnings on startup
@@ -186,6 +186,9 @@ class GitHub(object):
         Use this to make POST request since it will also encode ``data`` to
         'application/x-www-form-urlencoded' format."""
         headers = {'Content-Type': 'application/x-www-form-urlencoded'}
+        if "headers" in kwargs:
+            headers.update(kwargs["headers"])
+            del kwargs["headers"]
         data = json.dumps(data)
         return self.request('POST', resource, headers=headers,
                             data=data, **kwargs)
